package com.ruoyi.project.mapper;

import java.util.List;

import com.baomidou.mybatisplus.annotation.InterceptorIgnore;
import com.ruoyi.project.domain.TrsUrlResult;

/**
 * 错外链监测Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
public interface TrsUrlResultMapper 
{
    /**
     * 查询错外链监测
     * 
     * @param id 错外链监测主键
     * @return 错外链监测
     */
    public TrsUrlResult selectTrsUrlResultById(Long id);

    /**
     * 查询错外链监测列表
     * 
     * @param trsUrlResult 错外链监测
     * @return 错外链监测集合
     */
    public List<TrsUrlResult> selectTrsUrlResultList(TrsUrlResult trsUrlResult);

    @InterceptorIgnore(tenantLine = "true")
    public List<TrsUrlResult> selectTrsUrlResultList2(TrsUrlResult trsUrlResult);

    /**
     * 新增错外链监测
     * 
     * @param trsUrlResult 错外链监测
     * @return 结果
     */
    public int insertTrsUrlResult(TrsUrlResult trsUrlResult);

    /**
     * 修改错外链监测
     * 
     * @param trsUrlResult 错外链监测
     * @return 结果
     */
    @InterceptorIgnore(tenantLine = "true")
    public int updateTrsUrlResult(TrsUrlResult trsUrlResult);

    /**
     * 删除错外链监测
     * 
     * @param id 错外链监测主键
     * @return 结果
     */
    public int deleteTrsUrlResultById(Long id);

    /**
     * 批量删除错外链监测
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTrsUrlResultByIds(String[] ids);

    Long selectId(String datakey);
}
